@@ -18,7 +18,7 @@ var searchData=
   ['tablecharts_2eidl_15',['TableCharts.idl',['../TableCharts_8idl.html',1,'']]],
   ['tablechartsenumeration_2eidl_16',['TableChartsEnumeration.idl',['../TableChartsEnumeration_8idl.html',1,'']]],
   ['tablecolumn_2eidl_17',['TableColumn.idl',['../TableColumn_8idl.html',1,'']]],
-  ['tablecolumns_2eidl_18',['TableColumns.idl',['../text_2TableColumns_8idl.html',1,'(Global Namespace)'],['../table_2TableColumns_8idl.html',1,'(Global Namespace)']]],
+  ['tablecolumns_2eidl_18',['TableColumns.idl',['../table_2TableColumns_8idl.html',1,'(Global Namespace)'],['../text_2TableColumns_8idl.html',1,'(Global Namespace)']]],
   ['tablecolumnsenumeration_2eidl_19',['TableColumnsEnumeration.idl',['../TableColumnsEnumeration_8idl.html',1,'']]],
   ['tablecolumnseparator_2eidl_20',['TableColumnSeparator.idl',['../TableColumnSeparator_8idl.html',1,'']]],
   ['tableconditionalentry_2eidl_21',['TableConditionalEntry.idl',['../TableConditionalEntry_8idl.html',1,'']]],
@@ -26,7 +26,7 @@ var searchData=
   ['tableconditionalformat_2eidl_23',['TableConditionalFormat.idl',['../TableConditionalFormat_8idl.html',1,'']]],
   ['tablecount_2eidl_24',['TableCount.idl',['../TableCount_8idl.html',1,'']]],
   ['tabledefinition_2eidl_25',['TableDefinition.idl',['../TableDefinition_8idl.html',1,'']]],
-  ['tabledescriptor_2eidl_26',['TableDescriptor.idl',['../sdb_2TableDescriptor_8idl.html',1,'(Global Namespace)'],['../sdbcx_2TableDescriptor_8idl.html',1,'(Global Namespace)']]],
+  ['tabledescriptor_2eidl_26',['TableDescriptor.idl',['../sdbcx_2TableDescriptor_8idl.html',1,'(Global Namespace)'],['../sdb_2TableDescriptor_8idl.html',1,'(Global Namespace)']]],
   ['tabledesign_2eidl_27',['TableDesign.idl',['../TableDesign_8idl.html',1,'']]],
   ['tablefilterfield_2eidl_28',['TableFilterField.idl',['../TableFilterField_8idl.html',1,'']]],
   ['tablefilterfield2_2eidl_29',['TableFilterField2.idl',['../TableFilterField2_8idl.html',1,'']]],
